@@ -12,11 +12,23 @@ import kombu  # noqa
 from django.conf import settings  # noqa
 if not settings.configured:
     settings.configure()
+try:
+    from django import setup as django_setup
+except ImportError:
+    pass
+else:
+    django_setup()
 
 # General configuration
 # ---------------------
 
-extensions = ['sphinx.ext.autodoc', 'sphinx.ext.coverage']
+extensions = [
+    'sphinx.ext.autodoc',
+    'sphinx.ext.intersphinx',
+    'sphinx.ext.coverage',
+    'sphinx.ext.viewcode',
+    'sphinx.ext.pngmath',
+]
 
 # Add any paths that contain templates here, relative to this directory.
 templates_path = ['.templates']
@@ -31,6 +43,23 @@ master_doc = 'index'
 project = 'Kombu'
 copyright = '2009-2016, Ask Solem'
 
+intersphinx_mapping = {
+    'python': ('http://docs.python.org/dev', None),
+    'celery': ('http://docs.celeryproject.org/en/latest', None),
+    'djcelery': ('http://django-celery.readthedocs.org/en/latest', None),
+    'cyme': ('http://cyme.readthedocs.org/en/latest', None),
+    'amqp': ('http://amqp.readthedocs.org/en/latest', None),
+    'vine': ('http://vine.readthedocs.org/en/latest', None),
+    'redis': ('http://redis-py.readthedocs.org/en/latest', None),
+    'django': ('http://django.readthedocs.org/en/latest', None),
+    'boto': ('http://boto.readthedocs.org/en/latest', None),
+    'sqlalchemy': ('http://sqlalchemy.readthedocs.org/en/latest', None),
+    'kazoo': ('http://kazoo.readthedocs.org/en/latest', None),
+    'pyzmq': ('http://pyzmq.readthedocs.org/en/latest', None),
+    'msgpack': ('http://pythonhosted.org/msgpack-python/', None),
+    'sphinx': ('http://www.sphinx-doc.org/en/stable/', None),
+}
+
 # The version info for the project you're documenting, acts as replacement for
 # |version| and |release|, also used in various other places throughout the
 # built documents.
